pypsa_geo_layers() takes a directory rather than individual files, so the
shipped sidecars are reached through this rather than reneuro_example().
Examples
list.files(reneuro_example_geo())
#> [1] "regions_offshore_base_s_5.geojson" "regions_onshore_base_s_5.geojson"